# -*- coding: utf-8 -*-
import os

import dataiku
import pandas as pd, numpy as np
from dataiku import pandasutils as pdu
from dataiku.customrecipe import *
from deepspeech.model import Model
import scipy.io.wavfile as wav


for k, v in get_recipe_config().items():
    locals()[k] = v

# These constants are tied to the shape of the graph used (changing them changes
# the geometry of the first layer), so make sure you use the same constants that
# were used during training
# Number of MFCC features to use
N_FEATURES = 26
# Size of the context window used for producing timesteps in the input vector
N_CONTEXT = 9

# Read recipe inputs
audios = dataiku.Folder(get_input_names_for_role('audios')[0])
weights = dataiku.Folder(get_input_names_for_role('weights')[0]).get_path()

model = os.path.join(weights, 'models', 'output_graph.pb')
alphabet = os.path.join(weights, 'models', 'alphabet.txt')
lm = os.path.join(weights, 'models', 'lm.binary')
trie = os.path.join(weights, 'models', 'trie')

ds = Model(model, N_FEATURES, N_CONTEXT, alphabet, int(BEAM_WIDTH))
ds.enableDecoderWithLM(alphabet, lm, trie, LM_WEIGHT,
                       WORD_COUNT_WEIGHT, VALID_WORD_COUNT_WEIGHT)


df = pd.DataFrame(columns=['path', 'text'])
idx = 0

for path in audios.list_paths_in_partition():
    path = path[1:]
    audio = os.path.join(audios.get_path(), path)

    fs, audio = wav.read(audio)

    text = ds.stt(audio, fs)
    df.loc[idx] = [path, text]
    idx += 1


# Write recipe outputs
detected_texts = dataiku.Dataset(get_output_names_for_role('text')[0])
detected_texts.write_with_schema(df)
