import os
import urllib
import tarfile

from dataiku.runnables import Runnable
import dataiku


class MyRunnable(Runnable):
    """The base interface for a Python runnable"""

    def __init__(self, project_key, config, plugin_config):
        """
        :param project_key: the project in which the runnable executes
        :param config: the dict of the configuration of the object
        :param plugin_config: contains the plugin settings
        """
        self.project_key = project_key
        self.config = config
        self.plugin_config = plugin_config
        self.client = dataiku.api_client()
        
    def get_progress_target(self):
        """
        If the runnable will return some progress info, have this function return a tuple of 
        (target, unit) where unit is one of: SIZE, FILES, RECORDS, NONE
        """
        return (100, 'NONE')

    def run(self, progress_callback):
        """
        Do stuff here. Can return a string or raise an exception.
        The progress_callback is a function expecting 1 value: current progress
        """
        output_folder_name = self.config['folder_name']

        # Creating new Managed Folder if needed
        project = self.client.get_project(self.project_key)

        for folder in project.list_managed_folders():
            if output_folder_name == folder['name']:
                output_folder = project.get_managed_folder(folder['id'])
                break
        else:
            output_folder = project.create_managed_folder(output_folder_name)

        output_folder_path = dataiku.Folder(output_folder.get_definition()["id"],
                                            project_key=self.project_key).get_path()
        
        
        url = 'https://github.com/mozilla/DeepSpeech/releases/download/v0.1.1/deepspeech-0.1.1-models.tar.gz'
        progress_callback(10)
        tmp = os.path.join(output_folder_path, 'tmp.tar.gz')
        urllib.request.urlretrieve(url, tmp)
        progress_callback(70)
        tar = tarfile.open(tmp)
        progress_callback(80)
        tar.extractall(path=output_folder_path)
        progress_callback(90)
        tar.close()
        
        os.remove(tmp)
        progress_callback(100)